@@ -56,7 +56,7 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
     gchar *arg[10];
     GRand *rand;
     gchar *tmp;
-    gchar *url;
+    //gchar *url;
     gchar **parse;
     gint width = 0, height = 0;
     GError *error;
@@ -113,6 +113,14 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
                 sscanf(argv[i], "%i", &height);
             }
 
+            if (g_ascii_strcasecmp(argn[i], "style") == 0) {
+                tmp = g_strrstr(argv[i], "width:");
+                sscanf(tmp + strlen("width:"), "%i", &width);
+                tmp = g_strrstr(argv[i], "height:");
+                sscanf(tmp + strlen("height:"), "%i", &height);
+            }
+
+
             if (g_ascii_strcasecmp(argn[i], "src") == 0 || g_ascii_strcasecmp(argn[i], "url") == 0) {
                 item = g_new0(ListItem, 1);
                 if (g_strrstr(argv[i], "XXmovies.apple.com")) { // tmp disabled, to reenable remove XX
@@ -301,8 +309,7 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
                 if (g_ascii_strcasecmp(argv[i], "true") == 0
                     || g_ascii_strcasecmp(argv[i], "yes") == 0
                     || g_ascii_strcasecmp(argv[i], "1") == 0
-                    || g_ascii_strcasecmp(argv[i], "") == 0
-                    || argv[i] == NULL) {
+                    || g_ascii_strcasecmp(argv[i], "") == 0 || argv[i] == NULL) {
                     force_streaming = TRUE;
                 } else {
                     force_streaming = FALSE;
@@ -423,7 +430,36 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
 
         };
     } else {
+        // printf("Non-Embed Mode\n");
+        for (i = 0; i < argc; i++) {
 
+            if (argn[i] == NULL)
+                continue;
+
+            printf("ARG: %s = %s\n", argn[i], argv[i]);
+
+            if (g_ascii_strcasecmp(argn[i], "src") == 0) {
+                item = g_new0(ListItem, 1);
+                if (g_strrstr(argv[i], "XXmovies.apple.com")) { // tmp disabled, to reenable remove XX
+                    tmp = g_strrstr(argv[i], "movies.");
+                    if (tmp != NULL && strlen(tmp) > strlen("movies.")) {
+                        tmp = tmp + strlen("movies.");
+                        g_snprintf(item->src, 4096, "http://www.%s", tmp);
+                    } else {
+                        g_strlcpy(item->src, argv[i], 4096);
+                    }
+                } else {
+                    g_strlcpy(item->src, argv[i], 4096);
+                }
+                item->streaming = streaming(item->src);
+                printf("this should match %s\n", item->src);
+                item->play = TRUE;
+                item->id = instance->nextid++;
+                instance->playlist = g_list_append(instance->playlist, item);
+                src = item;
+            }
+
+        }
     }
 
     nperror = NPN_GetValue(instance->mInstance, (NPNVariable) 17 /* NPNVSupportsWindowless */ ,
@@ -449,7 +485,11 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
         } else {
             loop = FALSE;
         }
+    } else {
+        // Having this event fire creates several instances of gmp at some websites
+        // postPlayStateChange(instance->mInstance, STATE_TRANSITIONING);
     }
+
     // link up src to href objects by id
     if (href != NULL && src != NULL) {
         src->hrefid = href->id;
@@ -474,10 +514,10 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
         if (qtsrc)
             qtsrc->streaming = TRUE;
     }
-    
+
     list_qualify_url(instance->playlist, instance->page_url);
-    
-    
+
+
 //    if (g_ascii_strcasecmp(instance->mimetype,"video/x-flv") == 0) {
 //      item->streaming = TRUE;
 //    }
@@ -485,13 +525,12 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
     // list_dump(instance->playlist);
 
     if (instance->hidden == TRUE || ((width == 0 || height == 0) && instance->mode != NP_FULL)) {
-
         if (item->streaming) {
             open_location(instance, item, FALSE);
             item->requested = 1;
         } else {
             item->requested = 1;
-            NPN_GetURLNotify(instance->mInstance, item->src, NULL, item);
+            instance->GetURLNotify(instance->mInstance, item->src, NULL, item);
         }
     }
 
@@ -528,7 +567,7 @@ void new_instance(CPlugin * instance, int16_t argc, char *argn[], char *argv[])
             g_error_free(error);
             error = NULL;
         }
-        NPN_GetURLNotify(instance->mInstance, href->src, NULL, href);
+        instance->GetURLNotify(instance->mInstance, href->src, NULL, href);
         g_free(app_name);
     }
 
@@ -558,13 +597,21 @@ gboolean streaming(gchar * url)
     if (g_ascii_strncasecmp(url, "dvd://", 6) == 0)
         ret = TRUE;
 
+    if (g_ascii_strncasecmp(url, "udp://", 6) == 0)
+        ret = TRUE;
+
     if (g_strrstr(url, ".m3u") != NULL)
         ret = TRUE;
 
-    if (g_strrstr(url, "stream") != NULL)
+    if (g_strrstr(url, "stream") != NULL) {
+        if (g_strrstr(url, "http://") == NULL)
+            ret = TRUE;
+    }
+
+    if (g_strrstr(url, "MSWMExt=.asf") != NULL)
         ret = TRUE;
 
-    if (g_ascii_strncasecmp(url, "file://", 7) == 0) {
+    if (ret == FALSE && g_ascii_strncasecmp(url, "file://", 7) == 0) {
         p = g_filename_from_uri(url, NULL, NULL);
         if (p != NULL) {
             if (g_file_test(p, G_FILE_TEST_EXISTS)) {
